# eric7.CodeFormatting.BlackUtilities

Module implementing some utility functions for the Black based code formatting.

### Global Attributes

None

### Classes

None

### Functions

aboutBlack | Slot to show an 'About Black' dialog.
compileRegExp | Function to compile a given regular expression.
getDefaultConfiguration | Function to generate a default set of configuration parameters.
validateRegExp | Function to validate a given regular expression.

## aboutBlack

aboutBlack()

Slot to show an 'About Black' dialog.

Up

## compileRegExp

compileRegExp(regexp)

Function to compile a given regular expression.

regexp (str)
  regular expression to be compiled

Return:
  compiled regular expression object

Return Type:
  re.Pattern

Up

## getDefaultConfiguration

getDefaultConfiguration()

Function to generate a default set of configuration parameters.

Return:
  dictionary containing the default parameters

Return Type:
  dict

Up

## validateRegExp

validateRegExp(regexp)

Function to validate a given regular expression.

regexp (str)
  regular expression to be validated

Return:
  tuple containing a flag indicating validity and an error message

Return Type:
  tuple of (bool, str)

Up